@@ -296,11 +296,20 @@ class QA:
                 issues.append("Microservices list is empty, please be patient.")
 
             # 2. Check every resource
-            for resource in self._filter_list(
+            stale_resources = self._filter_list(
                 "status", ["creating", "updating"], response["list"]["resources"]
-            ):
+            )
+            for resource in stale_resources:
                 issues += self._check_resource_issues(resource)
 
+            # 3. Check is instance is stuck in a stale status
+            if len(stale_resources) == 0:
+                logger.warning("Trying to call qainit to force QA update...")
+                self._qainit.force_update(response["list"]["hash"])
+                issues.append(
+                    "Your QA was in a stale status and has been fixed, launch `suite-py describe` again please."
+                )
+
         return issues
 
     def _check_resource_issues(self, resource):
